<?php
/**
 * Copyright (c) 2011 Bart Visscher <bartv@thisnet.nl>
 * This file is licensed under the Affero General Public License version 3 or
 * later.
 * See the COPYING-README file.
 */


OCP\JSON::checkLoggedIn();
OCP\JSON::checkAppEnabled('calendar');
OCP\JSON::callCheck();

$id = $_POST['id'];

try {
	OC_Calendar_Object::delete($id);
} catch(Exception $e) {
	OCP\JSON::error(array('data' => array('message'=>$e->getMessage())));
	exit;
}

OCP\JSON::success();